@@ -1,7 +1,13 @@
-import boto3
-import base64
+from dataclasses import dataclass
 from django.conf import settings
-
+from json import JSONDecodeError
+import base64
+import boto3
+import json
+@dataclass
+class SecretKeyException(Exception):
+    reason: str
+    message: str
 
 def get_secret(secret_name: str, region_name: str=None):
     from botocore.exceptions import ClientError
@@ -20,7 +26,7 @@ def get_secret(secret_name: str, region_name: str=None):
             SecretId=secret_name
         )
     except ClientError as e:
-        raise e
+        raise SecretKeyException("Could not connect to AWS secret manager", e.response['Error']['Message'])
     else:
         # Decrypts secret using the associated KMS CMK.
         # Depending on whether the secret is a string or binary, one of these fields will be populated.
@@ -30,7 +36,12 @@ def get_secret(secret_name: str, region_name: str=None):
             secret_response = base64.b64decode(
                 get_secret_value_response['SecretBinary'])
 
+        try:
+            secret_response = json.loads(secret_response)
+        except JSONDecodeError as e:
+            raise SecretKeyException("Invalid JSON response from AWS Secret Manager", e.msg)
+
         if secret_name in secret_response:
             return secret_response[secret_name]
         else:
-            raise ValueError("Invalid response from AWS Secret Manager")
+            raise SecretKeyException("Invalid response from AWS Secret Manager", "Missing secret in response")
