@@ -47,7 +47,10 @@ def get_offset_hours_from_float(float_number: float) -> str:
     return "{sign}{h}{m}".format(sign=sign, h=hours_display, m=minutes_display)
 
 
-def convert_datetime_to_time(date_time, date_time_format: str = settings.DATETIME_FORMAT) -> time:
+def convert_datetime_to_time(date_time, date_time_format: str = None) -> time:
+    if date_time_format == None:
+        date_time_format = settings.DATETIME_FORMAT
+    
     if isinstance(date_time, time):
         return date_time
     elif isinstance(date_time, str):
